@@ -110,7 +110,7 @@ def generate_report(opts):
         <style>
             body {
                 font-family: -apple-system,sans-serif;
-                background-color: #737678;
+                background-color: #929596;
             }
 
             .sidenav {
@@ -120,7 +120,7 @@ def generate_report(opts):
                 z-index: 1;
                 top: 0;
                 left: 0;
-                background-color: #383C40;
+                background-color: #24282b;
                 overflow-x: hidden;
                 border-style: ridge;
             }
@@ -129,9 +129,9 @@ def generate_report(opts):
                 padding: 12px 10px 8px 12px;
                 text-decoration: none;
                 font-size: 18px;
-                color: Black;
+                color: white;
                 display: block;
-                background-color: #383C40;
+                background-color: #24282b;
             }
 
             .main {
